%global momorel 2
Summary: A GNU general-purpose parser generator
Name: bison
Version: 3.0.4
Release: %{momorel}m%{?dist}
License: GPLv3+
Group: Development/Tools
Source: ftp://ftp.gnu.org/pub/gnu/bison/bison-%{version}.tar.xz
NoSource: 0
Patch0: %{name}-%{version}-c++-test-failure.patch
# testsuite dependency
BuildRequires: autoconf
BuildRequires: flex

URL: http://www.gnu.org/software/bison/
BuildRoot: %{_tmppath}/%{name}-root
BuildRequires: m4 >= 1.4
#java-1.7.0-openjdk-devel
Requires: m4 >= 1.4
Requires(post): /sbin/install-info
Requires(preun): /sbin/install-info

# bison contains a copy of gnulib.  As a copylib, gnulib was granted
# an exception that allows bundling it with other software.  For
# details, see:
# https://fedoraproject.org/wiki/Packaging:No_Bundled_Libraries#Exceptions
Provides: bundled(gnulib)

%description
Bison is a general purpose parser generator that converts a grammar
description for an LALR(1) context-free grammar into a C program to
parse that grammar. Bison can be used to develop a wide range of
language parsers, from ones used in simple desk calculators to complex
programming languages. Bison is upwardly compatible with Yacc, so any
correctly written Yacc grammar should work with Bison without any
changes. If you know Yacc, you shouldn't have any trouble using
Bison. You do need to be very proficient in C programming to be able
to use Bison. Bison is only needed on systems that are used for
development.

If your system will be used for C development, you should install
Bison.

%package devel
Summary: -ly library for development using Bison-generated parsers
Group: Development/Libraries
Provides: bison-static = %{version}-%{release}

%description devel
The bison-devel package contains the -ly library sometimes used by
programs using Bison-generated parsers.  If you are developing programs
using Bison, you might want to link with this library.  This library
is not required by all Bison-generated parsers, but may be employed by
simple programs to supply minimal support for the generated parsers.

# -ly is kept static.  It only contains two symbols: main and yyerror,
# and both of these are extremely simple (couple lines of C total).
# It doesn't really pay off to introduce a shared library for that.
#
# Therefore -devel subpackage could have been created as -static, but
# the split was done in Jan 2005, which predates current guidelines.
# Besides there is logic to that: the library is devel in the sense
# that the generated parser could be distributed together with other
# sources, and only bison-devel would be necessary to wrap the build.

%package runtime
Summary: Runtime support files used by Bison-generated parsers
Group: Development/Libraries

%description runtime
The bison-runtime package contains files used at runtime by parsers
that Bison generates.  Packages whose binaries contain parsers
generated by Bison should depend on bison-runtime to ensure that
these files are available.  See the Internationalization in the
Bison manual section for more information.

%prep
%setup -q
%patch0 -p1 -b .test

%build
%configure
%make

%check
make check
#make maintainer-check

%install
[ "%{buildroot}" != "/" ] && %__rm -rf %{buildroot}
%makeinstall

# remove
rm -f %{buildroot}%{_bindir}/yacc
rm -f %{buildroot}%{_mandir}/man1/yacc.1*
rm -f %{buildroot}%{_datadir}/info/dir

%find_lang %{name}
%find_lang %{name}-runtime

%post
if [ -f %{_infodir}/bison.info.bz2 ]; then # for --excludedocs
   /sbin/install-info %{_infodir}/bison.info %{_infodir}/dir --entry="* bison: (bison).                        The GNU parser generator." || :
fi

%preun
if [ $1 = 0 ]; then
    if [ -f %{_infodir}/bison.info.bz2 ]; then # for --excludedocs
      /sbin/install-info --delete %{_infodir}/bison.info %{_infodir}/dir --entry="* bison: (bison).                        The GNU parser generator." || :
    fi
fi

# The distribution contains also source files.  These are used by m4
# when the target parser file is generated.
%files -f %{name}.lang
%defattr(-,root,root)
%doc AUTHORS ChangeLog NEWS README THANKS TODO COPYING
%{_mandir}/*/bison*
%{_datadir}/bison
%{_datadir}/doc/bison
%{_infodir}/bison.info*
%{_bindir}/bison
%{_datadir}/aclocal/bison*.m4

%files -f %{name}-runtime.lang runtime
%doc COPYING

%files devel
%doc COPYING
%defattr(-,root,root)
%{_libdir}/liby.a

%clean
rm -rf %{buildroot}

%changelog
* Sat Jun  3 2017 Ichiro Nakai <ichiro@n.email.ne.jp>
- (3.0.4-2m)
- fix build

* Sat Aug 01 2015 Yohsuke Ooi <meke@momonga-linux.org>
- (3.0.4-1m)
- update to 3.0.4

* Fri Jan 16 2015 Yohsuke Ooi <meke@momonga-linux.org>
- (3.0.3-1m)
- update to 3.0.3

* Thu May  1 2014 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.0.2-1m)
- update to 3.0.2, bug fix release
- fix %%post and %%preun

* Thu Nov 14 2013 Yohsuke Ooi <meke@momonga-linux.org>
- (3.0.1-1m)
- update to 3.0.1

* Fri Aug  2 2013 Yohsuke Ooi <meke@momonga-linux.org>
- (3.0-1m)
- update to 3.0

* Sat May 18 2013 NARITA Koichi <pulsar@momonga-linux.org>
- (2.7.1-1m)
- update to 2.7.1

* Thu Nov  8 2012 SANUKI Masaru <sanuki@momonga-linux.org>
- (2.6.1-1m)
- update to 2.6.1

* Thu Jun 23 2011 NARITA Koichi <pulsar@momonga-linux.org>
- (2.4.3-4m)
- version down to 2.4.3

* Tue May 24 2011 NARITA Koichi <pulsar@momonga-linux.org>
- (2.5-1m)
- update to 2.5

* Mon Apr 11 2011 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (2.4.3-3m)
- rebuild for new GCC 4.6

* Sun Nov 28 2010 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (2.4.3-2m)
- rebuild for new GCC 4.5

* Thu Sep 16 2010 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (2.4.3-1m)
- version up
- merge fedora's changes in %%post and %%postun
- add BuildRequires

* Tue Aug 31 2010 Yohsuke Ooi <meke@momonga-linux.org>
- (2.4.2-2m)
- full rebuild for mo7 release

* Wed Apr 21 2010 Yohsuke Ooi <meke@momonga-linux.org>
- (2.4.2-1m)
- update to 2.4.2

* Sat Nov 14 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (2.4.1-3m)
- rebuild against gcc-4.4 and glibc-2.11

* Wed Jan 21 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (2.4.1-2m)
- rebuild against rpm-4.6

* Mon Dec 15 2008 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (2.4.1-1m)
- update to 2.4.1
- apply Patch0 for testcase #50 failure
-- https://savannah.gnu.org/support/?106555

* Wed Nov  5 2008 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (2.4-1m)
- update to 2.4

* Thu Apr 03 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.3-2m)
- rebuild against gcc43

* Sat Jun  2 2007 NARITA Koichi <pulsar@momonga-linux.org>
- (2.3-1m)
- update to 2.3

* Tue Dec 27 2005 Masahiro Takahata <takahata@momonga-linux.org>
- (2.1-1m)
- sync with fc-devel

* Fri Feb 25 2005 Kazuhiko <kazuhiko@fdiary.net>
- (1.875c-1m)
- sync with FC3
- add more documents

* Fri Feb 25 2005 Kazuhiko <kazuhiko@fdiary.net>
- (1.875-1m)
- version up

* Tue Mar 15 2004 Toru Hoshina <t@momonga-linux.org>
- (1.35-6m)
- revised spec for enabling rpm 4.2.

* Fri Nov 28 2003 Shotaro Kamio <skamio@momonga-linux.org>
- (1.35-5m)
- roll back to ver 1.35

* Sat Nov 15 2003 Shotaro Kamio <skamio@momonga-linux.org>
- (1.875-1m)
- version up
- bison-1.875-unusedlabel.patch from RawHide (1.875-5)

* Tue Oct 15 2002 Shigeyuki Yamashita <shige@cty-net.ne.jp>
- (1.35-4m)
- domo 1.50 ha mazui rashii... makimodoshi suma-so

* Mon Oct 14 2002 Shigeyuki Yamashita <shige@cty-net.ne.jp>
- (1.50-1m)
- version up.

* Mon Oct 14 2002 KOMATSU Shinichiro <koma2@jiro.c.u-tokyo.ac.jp>
- (1.35-3m)
- add %%dir %%{_datadir}/bison into %%files section

* Sun May 12 2002 Toru Hoshina <t@kondara.org>
- (1.35-2k)
- ver up.

* Tue Apr 30 2002 Kenta MURATA <muraken@kondara.org>
- (1.33-4k)
- /sbin/install-info -> info in PreReq.

* Wed Feb 13 2002 Tsutomu Yasuda <tom@kondara.org>
- (1.33-2k)
- update to 1.33
  fix URL.

* Thu Oct 25 2001 MATSUDA, Daiki <dyky@df-usa.com>
- (1.28-12k)
- revert to 1.28, because bison-1.29 does not build XFree86

* Sat Oct 20 2001 Motonobu Ichimura <famao@kondara.org>
- (1.29-2k)
- up to 1.29
- now original archive includes ja.po

* Wed Oct 17 2001 Toru Hoshina <t@kondara.org>
- (1.28-10k)
- rebuild against gettext 0.10.40.

* Sat Oct 13 2001 Masaru Sato <masachan@kondara.org>
- add URL tag

* Wed Oct 25 2000 MATSUDA, Daiki <dyky@df-usa.com>
- modifiled %post and %preun section from .gz to .bz2

* Sun Apr 02 2000 Takaaki Tabuchi <tab@kondara.org>
- merge redhat-6.2 (1.28-2).

* Fri Feb 25 2000 Shingo Akagaki <dora@kondara.org>
- more fix files section

* Fri Feb 25 2000 Shingo Akagaki <dora@kondara.org>
- change files section

* Thu Feb 03 2000 Preston Brown <pbrown@redhat.com>
- rebuild to gzip man page.

* Mon Nov 8 1999 Toru Hoshina <t@kondara.org>
- be a NoSrc :-P

* Sat Sep 18 1999 Norihito Ohmori <ohmori@flatout.org>
- add ja.po from japo ML

* Fri Jul 16 1999 Jeff Johnson <jbj@redhat.com>
- update to 1.28.

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com>
- auto rebuild in the new build environment (release 3)

* Mon Mar  8 1999 Jeff Johnson <jbj@redhat.com>
- configure with datadir=/usr/lib (#1386).

* Mon Feb 22 1999 Jeff Johnson <jbj@redhat.com>
- updated text in spec file.
- update to 1.27

* Thu Dec 17 1998 Cristian Gafton <gafton@redhat.com>
- build for glibc 2.1

* Fri Apr 24 1998 Prospector System <bugs@redhat.com>
- translations modified for de, fr, tr

* Wed Apr 08 1998 Cristian Gafton <gafton@redhat.com>
- built for Manhattan
- added build root

* Wed Oct 15 1997 Donnie Barnes <djb@redhat.com>
- various spec file cleanups

* Mon Jun 02 1997 Erik Troan <ewt@redhat.com>
- built against glibc
